/* -*- c++ -*- */
/*
 * Copyright 2004 Free Software Foundation, Inc.
 * 
 * This file is part of GNU Radio
 * 
 * GNU Radio is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2, or (at your option)
 * any later version.
 * 
 * GNU Radio is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with GNU Radio; see the file COPYING.  If not, write to
 * the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */

class gr_block;
typedef boost::shared_ptr<gr_block> gr_block_sptr;
%template(gr_block_sptr) boost::shared_ptr<gr_block>;

// support vectors of these...
namespace std {
  %template(x_vector_gr_block_sptr)	vector<gr_block_sptr>;
};

class gr_block {
 protected:
  gr_block (const std::string &name,
	     gr_io_signature_sptr input_signature,
	     gr_io_signature_sptr output_signature);

 public:
  
  virtual ~gr_block ();
  
  std::string name () const { return d_name; }
  gr_io_signature_sptr input_signature () const  { return d_input_signature; }
  gr_io_signature_sptr output_signature () const { return d_output_signature; }
  long unique_id () const { return d_unique_id; }

  int  output_multiple () const;
  double relative_rate () const;

  bool check_topology (int ninputs, int noutputs);

  // internal use
  gr_block_detail_sptr detail () const { return d_detail; }
  void set_detail (gr_block_detail_sptr detail) { d_detail = detail; }
};

%rename(block_ncurrently_allocated) gr_block_ncurrently_allocated;
long gr_block_ncurrently_allocated ();

%pythoncode %{
gr_block_sptr.__repr__ = lambda self: "<gr_block %s (%d)>" % (self.name(), self.unique_id ())
gr_block_sptr.block = lambda self: self
%}
